Description: spelling fixes on vavoom source. 
Author: gustavo panizzo <gfa@zumbi.com.ar>
Bug-Debian: http://bugs.debian.org/598406
Last-Update: 2012-02-17

--- vavoom-1.33.orig/source/vc_property.cpp
+++ vavoom-1.33/source/vc_property.cpp
@@ -137,7 +137,7 @@ bool VProperty::Define()
 	{
 		if (BaseProp->Flags & PROP_Final)
 		{
-			ParseError(Loc, "Property alaready has been declared final and cannot be overriden");
+			ParseError(Loc, "Property alaready has been declared final and cannot be overridden");
 		}
 		if (!Type.Equals(BaseProp->Type))
 		{
--- vavoom-1.33.orig/source/vc_expr_invoke.cpp
+++ vavoom-1.33/source/vc_expr_invoke.cpp
@@ -682,7 +682,7 @@ void VInvocation::CheckParams(VEmitConte
 			{
 				if (!(Func->ParamFlags[i] & FPARM_Optional))
 				{
-					ParseError(Loc, "Bad expresion");
+					ParseError(Loc, "Bad expression");
 				}
 				argsize += Func->ParamTypes[i].GetStackSize();
 			}
@@ -762,7 +762,7 @@ void VInvocation::CheckParams(VEmitConte
 		{
 			if (!Args[i]->Type.Equals(Func->ParamTypes[i]))
 			{
-				ParseError(Loc, "Bad expresion");
+				ParseError(Loc, "Bad expression");
 			}
 		}
 		else
--- vavoom-1.33.orig/source/mapinfo.cpp
+++ vavoom-1.33/source/mapinfo.cpp
@@ -777,103 +777,103 @@ static void ParseMapCommon(VScriptParser
 		//	These are stubs for now.
 		else if (sc->Check("cdid"))
 		{
-			GCon->Logf("Unimplemented MAPINFO comand cdid");
+			GCon->Logf("Unimplemented MAPINFO command cdid");
 			sc->ExpectString();
 		}
 		else if (sc->Check("noinventorybar"))
 		{
-			GCon->Logf("Unimplemented MAPINFO comand noinventorybar");
+			GCon->Logf("Unimplemented MAPINFO command noinventorybar");
 		}
 		else if (sc->Check("airsupply"))
 		{
-			GCon->Logf("Unimplemented MAPINFO comand airsupply");
+			GCon->Logf("Unimplemented MAPINFO command airsupply");
 			sc->ExpectNumber();
 		}
 		else if (sc->Check("sndseq"))
 		{
-			GCon->Logf("Unimplemented MAPINFO comand sndseq");
+			GCon->Logf("Unimplemented MAPINFO command sndseq");
 			sc->ExpectName8();
 		}
 		else if (sc->Check("sndinfo"))
 		{
-			GCon->Logf("Unimplemented MAPINFO comand sndinfo");
+			GCon->Logf("Unimplemented MAPINFO command sndinfo");
 			sc->ExpectName8();
 		}
 		else if (sc->Check("soundinfo"))
 		{
-			GCon->Logf("Unimplemented MAPINFO comand soundinfo");
+			GCon->Logf("Unimplemented MAPINFO command soundinfo");
 			sc->ExpectName8();
 		}
 		else if (sc->Check("allowcrouch"))
 		{
-			GCon->Logf("Unimplemented MAPINFO comand allowcrouch");
+			GCon->Logf("Unimplemented MAPINFO command allowcrouch");
 		}
 		else if (sc->Check("nocrouch"))
 		{
-			GCon->Logf("Unimplemented MAPINFO comand nocrouch");
+			GCon->Logf("Unimplemented MAPINFO command nocrouch");
 		}
 		else if (sc->Check("pausemusicinmenus"))
 		{
-			GCon->Logf("Unimplemented MAPINFO comand pausemusicinmenus");
+			GCon->Logf("Unimplemented MAPINFO command pausemusicinmenus");
 		}
 		else if (sc->Check("bordertexture"))
 		{
-			GCon->Logf("Unimplemented MAPINFO comand bordertexture");
+			GCon->Logf("Unimplemented MAPINFO command bordertexture");
 			sc->ExpectName8();
 		}
 		else if (sc->Check("f1"))
 		{
-			GCon->Logf("Unimplemented MAPINFO comand f1");
+			GCon->Logf("Unimplemented MAPINFO command f1");
 			sc->ExpectString();
 		}
 		else if (sc->Check("allowrespawn"))
 		{
-			GCon->Logf("Unimplemented MAPINFO comand allowrespawn");
+			GCon->Logf("Unimplemented MAPINFO command allowrespawn");
 		}
 		else if (sc->Check("teamdamage"))
 		{
-			GCon->Logf("Unimplemented MAPINFO comand teamdamage");
+			GCon->Logf("Unimplemented MAPINFO command teamdamage");
 			sc->ExpectFloat();
 		}
 		else if (sc->Check("fogdensity"))
 		{
-			GCon->Logf("Unimplemented MAPINFO comand fogdensity");
+			GCon->Logf("Unimplemented MAPINFO command fogdensity");
 			sc->ExpectNumber();
 		}
 		else if (sc->Check("outsidefogdensity"))
 		{
-			GCon->Logf("Unimplemented MAPINFO comand outsidefogdensity");
+			GCon->Logf("Unimplemented MAPINFO command outsidefogdensity");
 			sc->ExpectNumber();
 		}
 		else if (sc->Check("skyfog"))
 		{
-			GCon->Logf("Unimplemented MAPINFO comand skyfog");
+			GCon->Logf("Unimplemented MAPINFO command skyfog");
 			sc->ExpectNumber();
 		}
 		else if (sc->Check("teamplayon"))
 		{
-			GCon->Logf("Unimplemented MAPINFO comand teamplayon");
+			GCon->Logf("Unimplemented MAPINFO command teamplayon");
 		}
 		else if (sc->Check("teamplayoff"))
 		{
-			GCon->Logf("Unimplemented MAPINFO comand teamplayoff");
+			GCon->Logf("Unimplemented MAPINFO command teamplayoff");
 		}
 		else if (sc->Check("checkswitchrange"))
 		{
-			GCon->Logf("Unimplemented MAPINFO comand checkswitchrange");
+			GCon->Logf("Unimplemented MAPINFO command checkswitchrange");
 		}
 		else if (sc->Check("nocheckswitchrange"))
 		{
-			GCon->Logf("Unimplemented MAPINFO comand nocheckswitchrange");
+			GCon->Logf("Unimplemented MAPINFO command nocheckswitchrange");
 		}
 		else if (sc->Check("translator"))
 		{
-			GCon->Logf("Unimplemented MAPINFO comand translator");
+			GCon->Logf("Unimplemented MAPINFO command translator");
 			sc->ExpectString();
 		}
 		else if (sc->Check("unfreezesingleplayerconversations"))
 		{
-			GCon->Logf("Unimplemented MAPINFO comand unfreezesingleplayerconversations");
+			GCon->Logf("Unimplemented MAPINFO command unfreezesingleplayerconversations");
 		}
 		else
 		{
@@ -1143,7 +1143,7 @@ static void ParseClusterDef(VScriptParse
 		{
 			sc->Check("lookup");
 			sc->ExpectString();
-			GCon->Logf("Unimplemented MAPINFO cluster comand name");
+			GCon->Logf("Unimplemented MAPINFO cluster command name");
 		}
 		else
 		{

--- vavoom-1.33.orig/source/vc_method.cpp
+++ vavoom-1.33/source/vc_method.cpp
@@ -263,7 +263,7 @@ bool VMethod::Define()
 		}
 	}
 
 	//	If this is a overriden method, verify that return type and argument
 	// types match.
 	SuperMethod = NULL;
 	if (Outer->MemberType == MEMBER_Class && Name != NAME_None &&
@@ -275,7 +275,7 @@ bool VMethod::Define()
 	{
 		if (SuperMethod->Flags & FUNC_Final)
 		{
-			ParseError(Loc, "Method already has been declared as final and cannot be overriden.");
+			ParseError(Loc, "Method already has been declared as final and cannot be overridden.");
 			Ret = false;
 		}
 		if (!SuperMethod->ReturnType.Equals(ReturnType))
@@ -263,7 +263,7 @@ bool VMethod::Define()
 	}
 
-	//	If this is a overriden method, verify that return type and argument
+	//	If this is a overridden method, verify that return type and argument
 	// types match.
 	SuperMethod = NULL;